# mypy-boto3-elasticbeanstalk

[![PyPI - mypy-boto3-elasticbeanstalk](https://img.shields.io/pypi/v/mypy-boto3-elasticbeanstalk.svg?color=blue)](https://pypi.org/project/mypy-boto3-elasticbeanstalk)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-elasticbeanstalk.svg?color=blue)](https://pypi.org/project/mypy-boto3-elasticbeanstalk)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

- [mypy-boto3-elasticbeanstalk](#mypy-boto3-elasticbeanstalk)
  - [How to use](#how-to-use)
  - [Automated type discovery](#automated-type-discovery)

Type annotations for
[boto3.ElasticBeanstalk 1.13.26](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/elasticbeanstalk.html#ElasticBeanstalk) service
compatible with [mypy](https://github.com/python/mypy), [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/) and other tools.

Generated by [mypy-boto3-buider 2.0.4](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

## How to use

Make sure you have [mypy](https://github.com/python/mypy) installed and activated in your IDE.

Install `boto3-stubs` for `ElasticBeanstalk` service.

```bash
python -m pip install boto3-stubs[elasticbeanstalk]
```

Use `boto3` with `mypy_boto3_elasticbeanstalk` in your project and enjoy type checking and auto-complete.

```python
import boto3

from mypy_boto3_elasticbeanstalk import ElasticBeanstalkClient

# Now mypy can check if your code is valid.
client: ElasticBeanstalkClient = boto3.client("elasticbeanstalk")

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: ElasticBeanstalkClient = session.client("elasticbeanstalk")



# Annotated paginators are included as well

import mypy_boto3_elasticbeanstalk.paginator as elasticbeanstalk_paginators

describe_application_versions_paginator: elasticbeanstalk_paginators.DescribeApplicationVersionsPaginator = client.get_paginator("describe_application_versions")
describe_environment_managed_action_history_paginator: elasticbeanstalk_paginators.DescribeEnvironmentManagedActionHistoryPaginator = client.get_paginator("describe_environment_managed_action_history")
describe_environments_paginator: elasticbeanstalk_paginators.DescribeEnvironmentsPaginator = client.get_paginator("describe_environments")
describe_events_paginator: elasticbeanstalk_paginators.DescribeEventsPaginator = client.get_paginator("describe_events")
list_platform_versions_paginator: elasticbeanstalk_paginators.ListPlatformVersionsPaginator = client.get_paginator("list_platform_versions")
```

## Dynamic type annotations

`mypy_boto3` command generates `boto3.client/resource` type annotations for
`mypy_boto3_elasticbeanstalk` and other installed services.

```bash
# Run this command after you add or remove service packages
python -m mypy_boto3
```

Generated type annotations provide overloads for `boto3.client` and `boto3.resource`,
`boto3.Session.client` and `boto3.Session.resource` functions,
so explicit type annotations are not needed.

- `mypy` supports function overloads as expected
- `PyCharm` also supports function overloads, but consumes a lot of RAM, use carefully if you have many services installed
- `VSCode` does not currently support function overloads, use explicit type annotations

```python
import boto3

# Type is discovered correctly by mypy and PyCharm
# VSCode still needs explicit type annotations
client = boto3.client("elasticbeanstalk")

session_client = boto3.Session().client("elasticbeanstalk")
```